@@ -18,7 +18,7 @@ SUBROUTINE cprmain( tau_out, fion_out, etot_out )
                                        ndr, ndw, nomore, tsde, textfor,        &
                                        tortho, tnosee, tnosep, trane, tranp,   &
                                        tsdp, tcp, tcap, ampre, amprp, tnoseh,  &
-                                       tolp, ortho_eps, ortho_max, printwfc
+                                       tolp, ortho_eps, ortho_max
   USE core,                     ONLY : rhoc
   USE uspp_param,               ONLY : nhm, nh, nvb, ish
   USE uspp,                     ONLY : nkb, vkb, becsum, deeq, okvan, nlcc_any
@@ -295,6 +295,10 @@ SUBROUTINE cprmain( tau_out, fion_out, etot_out )
      IF ( ( tfor .OR. tfirst ) .AND. tefield ) CALL efield_update( eigr )
      IF ( ( tfor .OR. tfirst ) .AND. tefield2 ) CALL efield_update2( eigr )
      !
+     ! ... pass ions information to plugins
+     !
+     CALL plugin_init_ions( tau0 )
+     !
      IF ( lda_plus_u ) then
         ! forceh    ! Forces on ions due to Hubbard U 
         forceh=0.0d0
@@ -801,6 +805,8 @@ SUBROUTINE cprmain( tau_out, fion_out, etot_out )
            IF ( tefield )  CALL efield_update( eigr )
            IF ( tefield2 ) CALL efield_update2( eigr )
            !
+           CALL plugin_init_ions( tau0 )
+           !
            lambdam = lambda
            !
            CALL move_electrons( nfi, tfirst, tlast, bg(:,1), bg(:,2), bg(:,3),&
@@ -1128,6 +1134,8 @@ SUBROUTINE terminate_run()
   !
   CALL print_clock( 'ALLTOALL' )
   !
+  CALL plugin_clock()
+  !
   CALL mp_report()
   !
 END SUBROUTINE terminate_run
