@@ -34,8 +34,8 @@
       use gvecs,                only: gcutms, gvecs_init
       use gvecw,                only: gkcut, gvecw_init, g2kin_init
       USE smallbox_subs,        ONLY: ggenb
-      USE fft_base,             ONLY: dfftp, dffts, dfftb
-      USE fft_scalar,           ONLY: cft_b_omp_init
+      USE fft_base,             ONLY: dfftp, dffts, dfftb, dfft3d
+      USE fft_smallbox,         ONLY: cft_b_omp_init
       USE stick_set,            ONLY: pstickset
       USE control_flags,        ONLY: gamma_only, smallmem
       USE electrons_module,     ONLY: bmeshset
@@ -95,11 +95,13 @@
         !
         CALL realspace_grid_init( dfftp, ref_at, ref_bg, gcutm )
         CALL realspace_grid_init( dffts, ref_at, ref_bg, gcutms)
+        CALL realspace_grid_init( dfft3d, ref_at, ref_bg, gcutms)
         !
       ELSE
         !
         CALL realspace_grid_init( dfftp, at, bg, gcutm )
         CALL realspace_grid_init( dffts, at, bg, gcutms)
+        CALL realspace_grid_init( dfft3d, at, bg, gcutms)
         !
       END IF
       !
@@ -136,7 +138,7 @@
 
       CALL pstickset( gamma_only, bg, gcutm, gkcut, gcutms, &
         dfftp, dffts, ngw_ , ngm_ , ngs_ , me_bgrp, root_bgrp, &
-        nproc_bgrp, intra_bgrp_comm, ntask_groups )
+        nproc_bgrp, intra_bgrp_comm, ntask_groups, ionode, stdout, dfft3d )
       !
       !
       ! ... Initialize reciprocal space local and global dimensions
@@ -208,7 +210,7 @@
          !
          CALL ggenb ( ecutrho, iverbosity )
          !
-#if defined __OPENMP && defined __FFTW 
+#if defined __OPENMP
          CALL cft_b_omp_init( dfftb%nr1, dfftb%nr2, dfftb%nr3 )
 #endif
       ELSE IF( okvan .OR. nlcc_any ) THEN
@@ -229,7 +231,7 @@
       !
       !   Flush stdout
       !
-      CALL flush_unit( stdout )
+      FLUSH( stdout )
       !
       CALL stop_clock( 'init_dim' )
       !
@@ -419,5 +421,9 @@
       !
       call gcalb ( )
       !
+      !   pass new cell parameters to plugins
+      !
+      CALL plugin_init_cell( )
+      !
       return
     end subroutine newinit_x
