@@ -2,7 +2,11 @@
 # Associate labels original text with physical files.
 
 
-$key = q/SubSec:Merge/;
+$key = q/SubSec:CPP/;
+$external_labels{$key} = "$URL/" . q|developer_man.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/SubSec:Inst/;
 $external_labels{$key} = "$URL/" . q|developer_man.html|; 
 $noresave{$key} = "$nosave";
 
@@ -10,6 +14,10 @@ $key = q/SubSec:Conflicts/;
 $external_labels{$key} = "$URL/" . q|developer_man.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/SubSec:Bugs/;
+$external_labels{$key} = "$URL/" . q|developer_man.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/SubSec:conf/;
 $external_labels{$key} = "$URL/" . q|developer_man.html|; 
 $noresave{$key} = "$nosave";
@@ -18,22 +26,14 @@ $key = q/Sec:SVN/;
 $external_labels{$key} = "$URL/" . q|developer_man.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/SubSec:Merge/;
+$external_labels{$key} = "$URL/" . q|developer_man.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/SubSec:propedit/;
 $external_labels{$key} = "$URL/" . q|developer_man.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/SubSec:CPP/;
-$external_labels{$key} = "$URL/" . q|developer_man.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/SubSec:Bugs/;
-$external_labels{$key} = "$URL/" . q|developer_man.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/SubSec:Inst/;
-$external_labels{$key} = "$URL/" . q|developer_man.html|; 
-$noresave{$key} = "$nosave";
-
 1;
 
 
@@ -41,8 +41,12 @@ $noresave{$key} = "$nosave";
 # labels from external_latex_labels array.
 
 
-$key = q/SubSec:Conflicts/;
-$external_latex_labels{$key} = q|11.2|; 
+$key = q/SubSec:propedit/;
+$external_latex_labels{$key} = q|11.4|; 
+$noresave{$key} = "$nosave";
+
+$key = q/SubSec:Merge/;
+$external_latex_labels{$key} = q|11.3|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SubSec:conf/;
@@ -53,28 +57,24 @@ $key = q/Sec:SVN/;
 $external_latex_labels{$key} = q|11|; 
 $noresave{$key} = "$nosave";
 
-$key = q/SubSec:Merge/;
-$external_latex_labels{$key} = q|11.3|; 
-$noresave{$key} = "$nosave";
-
-$key = q/_/;
-$external_latex_labels{$key} = q|<|; 
-$noresave{$key} = "$nosave";
-
-$key = q/SubSec:CPP/;
-$external_latex_labels{$key} = q|5.1.1|; 
+$key = q/SubSec:Bugs/;
+$external_latex_labels{$key} = q|3.5|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SubSec:Inst/;
 $external_latex_labels{$key} = q|5.1|; 
 $noresave{$key} = "$nosave";
 
-$key = q/SubSec:Bugs/;
-$external_latex_labels{$key} = q|3.5|; 
+$key = q/SubSec:CPP/;
+$external_latex_labels{$key} = q|5.1.1|; 
 $noresave{$key} = "$nosave";
 
-$key = q/SubSec:propedit/;
-$external_latex_labels{$key} = q|11.4|; 
+$key = q/SubSec:Conflicts/;
+$external_latex_labels{$key} = q|11.2|; 
+$noresave{$key} = "$nosave";
+
+$key = q/_oldnewlabel/;
+$external_latex_labels{$key} = q|<|; 
 $noresave{$key} = "$nosave";
 
 1;
