@@ -236,9 +236,6 @@ MODULE input_parameters
           !          files
           ! Only for PW and only in the parallel case
 
-        INTEGER :: printwfc=1
-          ! if <0 do nothing, if==0 print rho and fort.47, if == nband print band
-
         LOGICAL :: saverho = .true.
           ! This flag controls the saving of charge density in CP codes:
           !  .TRUE.  save charge density to restart dir
@@ -274,16 +271,19 @@ MODULE input_parameters
 
         LOGICAL  :: lfcpopt = .FALSE. ! FCP optimisation switch
         LOGICAL  :: lfcpdyn = .FALSE. ! FCP thermostat enabled if .true.
+        !
+        ! location of xml input according to xsd schema
+        CHARACTER(len=256) :: input_xml_schema_file = ' '
 
         NAMELIST / control / title, calculation, verbosity, restart_mode, &
           nstep, iprint, isave, tstress, tprnfor, dt, ndr, ndw, outdir,   &
           prefix, wfcdir, max_seconds, ekin_conv_thr, etot_conv_thr,      &
           forc_conv_thr, pseudo_dir, disk_io, tefield, dipfield, lberry,  &
-          gdir, nppstr, wf_collect, printwfc, lelfield, nberrycyc, refg,  &
+          gdir, nppstr, wf_collect, lelfield, nberrycyc, refg,            &
           tefield2, saverho, tabps, lkpoint_dir, use_wannier, lecrpa,     &
           tqmmm, vdw_table_name, lorbm, memory, point_label_type,         &
-          lcalc_z2, z2_m_threshold, z2_z_threshold, lfcpopt, lfcpdyn
-
+          lcalc_z2, z2_m_threshold, z2_z_threshold, lfcpopt, lfcpdyn,     &
+          input_xml_schema_file                                                  
 !
 !=----------------------------------------------------------------------------=!
 !  SYSTEM Namelist Input Parameters
@@ -937,7 +937,7 @@ MODULE input_parameters
           diis_temp, diis_achmix, diis_g0chmix, diis_g1chmix,          &
           diis_nchmix, diis_nrot, diis_rothr, diis_ethr, diis_chguess, &
           mixing_mode, mixing_beta, mixing_ndim, mixing_fixed_ns,      &
-          tqr, diago_cg_maxiter, diago_david_ndim, diagonalization ,   &
+          tqr, diago_cg_maxiter, diago_david_ndim, diagonalization,    &
           startingpot, startingwfc , conv_thr,                         &
           adaptive_thr, conv_thr_init, conv_thr_multi,                 &
           diago_thr_init, n_inner, fermi_energy, rotmass, occmass,     &
