@@ -87,16 +87,16 @@ MODULE read_namelists_module
        ! ... use the path specified as outdir and the filename prefix
        ! ... to store output data
        !
-       CALL get_env( 'ESPRESSO_TMPDIR', outdir )
+       CALL get_environment_variable( 'ESPRESSO_TMPDIR', outdir )
        IF ( TRIM( outdir ) == ' ' ) outdir = './'
        IF( prog == 'PW' ) prefix = 'pwscf'
        IF( prog == 'CP' ) prefix = 'cp'
        !
        ! ... directory containing the pseudopotentials
        !
-       CALL get_env( 'ESPRESSO_PSEUDO', pseudo_dir )
+       CALL get_environment_variable( 'ESPRESSO_PSEUDO', pseudo_dir )
        IF ( TRIM( pseudo_dir ) == ' ') THEN
-          CALL get_env( 'HOME', pseudo_dir )
+          CALL get_environment_variable( 'HOME', pseudo_dir )
           pseudo_dir = TRIM( pseudo_dir ) // '/espresso/pseudo/'
        END IF
        !
@@ -115,7 +115,6 @@ MODULE read_namelists_module
        nppstr   = 0
        wf_collect = .FALSE.
        IF( prog == 'CP' ) wf_collect = .TRUE.  ! default for CP is true
-       printwfc = -1
        lelfield = .FALSE.
        lorbm = .FALSE.
        nberrycyc  = 1
@@ -129,6 +128,10 @@ MODULE read_namelists_module
        lfcpopt = .FALSE.
        lfcpdyn = .FALSE.
        !
+       CALL get_environment_variable( 'QEXML', input_xml_schema_file )
+       IF ( TRIM(input_xml_schema_file) == ' ') &
+          input_xml_schema_file='./qes.xsd'
+       !
        RETURN
        !
      END SUBROUTINE
@@ -230,7 +233,7 @@ MODULE read_namelists_module
        B_field = 0.0_DP
        angle1 = 0.0_DP
        angle2 = 0.0_DP
-       report = 1
+       report = 100
        !
        no_t_rev = .FALSE.
        !
@@ -453,7 +456,7 @@ MODULE read_namelists_module
        ion_velocities = 'default'
        !
        ! ... ( 'nose' | 'not_controlled' | 'rescaling' | 'berendsen' |
-       !       'andersen' | 'langevin' )
+       !       'andersen' | 'initial' )
        !
        ion_temperature = 'not_controlled'
        !
@@ -648,6 +651,22 @@ MODULE read_namelists_module
      !
      !=----------------------------------------------------------------------=!
      !
+#ifdef __XSD
+     !-----------------------------------------------------------------------
+     SUBROUTINE xsd_bcast()
+     !-----------------------------------------------------------------------
+       !
+       USE io_global, ONLY : ionode_id
+       USE mp,        ONLY : mp_bcast
+       USE mp_images, ONLY : intra_image_comm
+       !
+       IMPLICIT NONE
+       !
+       CALL mp_bcast( input_xml_schema_file, ionode_id, intra_image_comm )
+       !
+     END SUBROUTINE
+#endif
+     !
      !-----------------------------------------------------------------------
      SUBROUTINE control_bcast()
        !-----------------------------------------------------------------------
@@ -693,7 +712,6 @@ MODULE read_namelists_module
        CALL mp_bcast( point_label_type,   ionode_id, intra_image_comm )
        CALL mp_bcast( lkpoint_dir,   ionode_id, intra_image_comm )
        CALL mp_bcast( wf_collect,    ionode_id, intra_image_comm )
-       CALL mp_bcast( printwfc,      ionode_id, intra_image_comm )
        CALL mp_bcast( lelfield,      ionode_id, intra_image_comm )
        CALL mp_bcast( lorbm,         ionode_id, intra_image_comm )
        CALL mp_bcast( nberrycyc,     ionode_id, intra_image_comm )
@@ -704,6 +722,7 @@ MODULE read_namelists_module
        CALL mp_bcast( memory,        ionode_id, intra_image_comm )
        CALL mp_bcast( lfcpopt,       ionode_id, intra_image_comm )
        CALL mp_bcast( lfcpdyn,       ionode_id, intra_image_comm )
+       CALL mp_bcast( input_xml_schema_file, ionode_id, intra_image_comm )
        !
        RETURN
        !
@@ -1322,7 +1341,7 @@ MODULE read_namelists_module
        IF( nspin < 1 .OR. nspin > 4 .OR. nspin == 3 ) &
           CALL errore( sub_name ,' nspin out of range ', MAX(nspin, 1 ) )
        !
-       IF( ecutwfc <= 0.0_DP ) &
+       IF( ecutwfc < 0.0_DP ) &
           CALL errore( sub_name ,' ecutwfc out of range ',1)
        IF( ecutrho < 0.0_DP ) &
           CALL errore( sub_name ,' ecutrho out of range ',1)
@@ -1776,6 +1795,7 @@ MODULE read_namelists_module
        !
        ! ... Here start reading standard input file
        !
+       !
        ! ... CONTROL namelist
        !
        IF(prog == 'PW' .OR. prog == 'CP' ) THEN
