@@ -10,7 +10,6 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
   !-----------------------------------------------------------------------
   !
   USE io_global,  ONLY : stdout
-  USE basis, ONLY : natomwfc
   USE ions_base, ONLY : ityp, atm
   USE klist, ONLY: wk, nkstot, degauss, ngauss, lgauss
   USE lsda_mod, ONLY: nspin, isk, current_spin
@@ -28,13 +27,16 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
   CHARACTER (len=256):: fileout
   CHARACTER (len=1)  :: l_label(0:3)=(/'s','p','d','f'/)
   !
-  INTEGER :: ik, ibnd,  m, &
+  INTEGER :: nproj, ik, ibnd,  m, &
        c_tab, nwfc, ne, ie_mid, ie_delta, ie, is, nkseff, ikeff
   REAL(DP) :: etev, delta, Elw, Eup, wkeff
   REAL(DP), ALLOCATABLE :: dostot(:,:,:), pdos(:,:,:,:), pdostot(:,:,:), &
        ldos(:,:,:)
   REAL(DP), EXTERNAL :: w0gauss
   !
+  ! this can be either natomwfc or nkb, depending upon the projection
+  !
+  nproj = SIZE(proj,1)
   !
   ! find band extrema
   !
@@ -63,7 +65,7 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
      nkseff=1
   ENDIF
   !
-  ALLOCATE (pdos(0:ne,natomwfc,nspin,nkseff))
+  ALLOCATE (pdos(0:ne,nproj,nspin,nkseff))
   ALLOCATE (dostot(0:ne,nspin,nkseff), pdostot(0:ne,nspin,nkseff), ldos(0:ne,nspin,nkseff) )
   pdos(:,:,:,:) = 0.d0
   dostot(:,:,:) = 0.d0
@@ -102,7 +104,7 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
            !                      projected over atomic wfc "nwfc"
            !                      for k-point "ik" (or summed over all kp)
            !
-           DO nwfc = 1, natomwfc
+           DO nwfc = 1, nproj
               pdos(ie,nwfc,current_spin,ikeff) = pdos(ie,nwfc,current_spin,ikeff) + &
                    wkeff * delta * proj (nwfc, ibnd, ik)
            ENDDO
@@ -126,7 +128,7 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
      ENDDO
   ENDDO
 
-  DO nwfc = 1, natomwfc
+  DO nwfc = 1, nproj
      IF (nlmchi(nwfc)%m == 1) THEN
         filextension='.pdos_atm#'
         !             12345678901
@@ -163,21 +165,21 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
              status='unknown')
 
         IF (kresolveddos) THEN
-           WRITE (4,'("# ik   "), advance="NO"')
+           WRITE (4,'("# ik   ")', advance="NO")
         ELSE
-           WRITE (4,'("#"), advance="NO"')
+           WRITE (4,'("#")', advance="NO")
         ENDIF
         IF (nspin == 1) THEN
-           WRITE (4,'(" E (eV)   ldos(E)  "), advance="NO"')
+           WRITE (4,'(" E (eV)   ldos(E)  ")', advance="NO")
         ELSE
-           WRITE (4,'(" E (eV)  ldosup(E)  ldosdw(E)"), advance="NO"')
+           WRITE (4,'(" E (eV)  ldosup(E)  ldosdw(E)")', advance="NO")
         ENDIF
         DO m=1,2 * nlmchi(nwfc)%l + 1
            IF (nspin == 1) THEN
-              WRITE(4,'(" pdos(E)   "), advance="NO"')
+              WRITE(4,'(" pdos(E)   ")', advance="NO")
            ELSE
-              WRITE(4,'(" pdosup(E) "), advance="NO"')
-              WRITE(4,'(" pdosdw(E) "), advance="NO"')
+              WRITE(4,'(" pdosup(E) ")', advance="NO")
+              WRITE(4,'(" pdosdw(E) ")', advance="NO")
            ENDIF
         ENDDO
         WRITE(4,*)
@@ -197,7 +199,7 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
         DO ik=1,nkseff
            DO ie= 0, ne
               IF (kresolveddos) THEN
-                 WRITE (4,'(i5," "), advance="NO"') ik
+                 WRITE (4,'(i5," ")', advance="NO") ik
               ENDIF
               etev = Emin + ie * DeltaE
               WRITE (4,'(f7.3,2e11.3,14e11.3)') etev*rytoev,  &
@@ -213,9 +215,9 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
   fileout = trim(filpdos)//".pdos_tot"
   OPEN (4,file=fileout,form='formatted', status='unknown')
   IF (kresolveddos) THEN
-     WRITE (4,'("# ik   "), advance="NO"')
+     WRITE (4,'("# ik   ")', advance="NO")
   ELSE
-     WRITE (4,'("#"), advance="NO"')
+     WRITE (4,'("#")', advance="NO")
   ENDIF
   IF (nspin == 1) THEN
      WRITE (4,'(" E (eV)  dos(E)    pdos(E)")')
@@ -225,7 +227,7 @@ SUBROUTINE  partialdos (Emin, Emax, DeltaE, kresolveddos, filpdos)
   DO ik=1,nkseff
      DO ie= 0, ne
         IF (kresolveddos) THEN
-           WRITE (4,'(i5," "), advance="NO"') ik
+           WRITE (4,'(i5," ")', advance="NO") ik
         ENDIF
         etev = Emin + ie * DeltaE
         WRITE (4,'(f7.3,4e11.3)') etev*rytoev, (dostot(ie,is,ik), is=1,nspin), &
@@ -414,14 +416,14 @@ SUBROUTINE  partialdos_nc (Emin, Emax, DeltaE, kresolveddos, filpdos)
              status='unknown')
 
         IF (kresolveddos) THEN
-           WRITE (4,'("# ik   "), advance="NO"')
+           WRITE (4,'("# ik   ")', advance="NO")
         ELSE
-           WRITE (4,'("#"), advance="NO"')
+           WRITE (4,'("#")', advance="NO")
         ENDIF
         IF (nspin0 == 1) THEN
-           WRITE (4,'(" E(eV)   ldos(E)   "), advance="NO"')
+           WRITE (4,'(" E(eV)   ldos(E)   ")', advance="NO")
         ELSE
-           WRITE (4,'(" E(eV)  ldosup(E)  ldosdw(E)"), advance="NO"')
+           WRITE (4,'(" E(eV)  ldosup(E)  ldosdw(E)")', advance="NO")
         ENDIF
         IF (lspinorb) THEN
            ind = 0
@@ -430,13 +432,13 @@ SUBROUTINE  partialdos_nc (Emin, Emax, DeltaE, kresolveddos, filpdos)
               fact(2) = spinor(nlmchi(nwfc)%l,nlmchi(nwfc)%jj,m,2)
               IF (abs(fact(1))>1.d-8.or.abs(fact(2))>1.d-8) THEN
                  ind = ind + 1
-                 WRITE(4,'("pdos(E)_",i1,"   "), advance="NO"') ind
+                 WRITE(4,'("pdos(E)_",i1,"   ")', advance="NO") ind
               ENDIF
            ENDDO
         ELSE
            DO ind=1,2 * nlmchi(nwfc)%l + 1
-              WRITE(4,'(" pdosup(E) "), advance="NO"')
-              WRITE(4,'(" pdosdw(E) "), advance="NO"')
+              WRITE(4,'(" pdosup(E) ")', advance="NO")
+              WRITE(4,'(" pdosdw(E) ")', advance="NO")
            ENDDO
         ENDIF
         WRITE(4,*)
@@ -461,7 +463,7 @@ SUBROUTINE  partialdos_nc (Emin, Emax, DeltaE, kresolveddos, filpdos)
            DO ik=1,nkseff
               DO ie= 0, ne
                  IF (kresolveddos) THEN
-                    WRITE (4,'(i5," "), advance="NO"') ik
+                    WRITE (4,'(i5," ")', advance="NO") ik
                  ENDIF
                  etev = Emin + ie * DeltaE
                  IF (abs(nlmchi(nwfc)%jj-nlmchi(nwfc)%l-0.5d0)<1.d-8) THEN
@@ -487,7 +489,7 @@ SUBROUTINE  partialdos_nc (Emin, Emax, DeltaE, kresolveddos, filpdos)
            DO ik=1,nkseff
               DO ie= 0, ne
                  IF (kresolveddos) THEN
-                    WRITE (4,'(i5," "), advance="NO"') ik
+                    WRITE (4,'(i5," ")', advance="NO") ik
                  ENDIF
                  etev = Emin + ie * DeltaE
                  WRITE (4,'(f7.3,2e11.3,14e11.3)') etev*rytoev,  &
@@ -504,9 +506,9 @@ SUBROUTINE  partialdos_nc (Emin, Emax, DeltaE, kresolveddos, filpdos)
   fileout = trim(filpdos)//".pdos_tot"
   OPEN (4,file=fileout,form='formatted', status='unknown')
   IF (kresolveddos) THEN
-     WRITE (4,'("# ik   "), advance="NO"')
+     WRITE (4,'("# ik   ")', advance="NO")
   ELSE
-     WRITE (4,'("#"), advance="NO"')
+     WRITE (4,'("#")', advance="NO")
   ENDIF
   IF (nspin0 == 1) THEN
      WRITE (4,'(" E (eV)  dos(E)    pdos(E)")')
@@ -516,7 +518,7 @@ SUBROUTINE  partialdos_nc (Emin, Emax, DeltaE, kresolveddos, filpdos)
   DO ik=1,nkseff
      DO ie= 0, ne
         IF (kresolveddos) THEN
-           WRITE (4,'(i5," "), advance="NO"') ik
+           WRITE (4,'(i5," ")', advance="NO") ik
         ENDIF
         etev = Emin + ie * DeltaE
         WRITE (4,'(f7.3,4e11.3)') etev*rytoev, dostot(ie,ik), &
