@@ -99,7 +99,7 @@ SUBROUTINE extract (filplot,plot_num)
   !   set default values for variables in namelist
   !
   prefix = 'pwscf'
-  CALL get_env( 'ESPRESSO_TMPDIR', outdir )
+  CALL get_environment_variable( 'ESPRESSO_TMPDIR', outdir )
   IF ( trim( outdir ) == ' ' ) outdir = './'
   filplot = 'tmp.pp'
   plot_num = -1
