@@ -167,7 +167,7 @@ SUBROUTINE c_phase
    USE klist,                ONLY : nelec, degauss, nks, xk, wk
    USE wvfct,                ONLY : npwx, npw, nbnd, ecutwfc, wg
    USE wavefunctions_module, ONLY : evc
-   USE bp,                   ONLY : gdir, nppstr, mapgm_global
+   USE bp,                   ONLY : gdir, nppstr, mapgm_global, pdl_tot
    USE becmod,               ONLY : calbec, bec_type, allocate_bec_type, &
                                     deallocate_bec_type
    USE noncollin_module,     ONLY : noncolin, npol, nspin_lsda
@@ -254,7 +254,6 @@ SUBROUTINE c_phase
    REAL(DP) :: pdl_elec_up
    REAL(DP) :: pdl_ion(nat)
    REAL(DP) :: pdl_ion_tot
-   REAL(DP) :: pdl_tot
    REAL(DP) :: phidw
    REAL(DP) :: phiup
    REAL(DP) :: rmod
@@ -983,7 +982,6 @@ SUBROUTINE c_phase
       IF (lspinorb) DEALLOCATE(q_dk_so)
    END IF
 
-
 !------------------------------------------------------------------------------!
 
 END SUBROUTINE c_phase
