@@ -25,7 +25,8 @@ SUBROUTINE electrons()
                                    elondon, ef_up, ef_dw
   USE scf,                  ONLY : rho, rho_core, rhog_core, v, vltot, vrs, &
                                    kedtau, vnew
-  USE control_flags,        ONLY : tr2, niter, conv_elec, restart, lmd
+  USE control_flags,        ONLY : tr2, niter, conv_elec, restart, lmd, &
+                                   do_makov_payne
   USE io_files,             ONLY : iunwfc, iunmix, nwordwfc, output_drho, &
                                    iunres, iunefield, seqopn
   USE buffers,              ONLY : save_buffer, close_buffer
@@ -213,6 +214,7 @@ SUBROUTINE electrons()
         WRITE( stdout, 9064 ) 0.5D0*fock2
         !
         IF ( dexx < tr2_final ) THEN
+           IF ( do_makov_payne ) CALL makov_payne( etot )
            WRITE( stdout, 9101 )
            RETURN
         END IF
@@ -242,7 +244,7 @@ SUBROUTINE electrons()
   END DO
   !
   WRITE( stdout, 9120 ) iter
-  CALL flush_unit( stdout )
+  FLUSH( stdout )
   !
   RETURN
   !
@@ -295,7 +297,7 @@ SUBROUTINE electrons_scf ( printout )
                                    rho, rho_core, rhog_core, v, vltot, vrs, &
                                    kedtau, vnew
   USE control_flags,        ONLY : mixing_beta, tr2, ethr, niter, nmix, &
-                                   iprint, istep, conv_elec, &
+                                   iprint, conv_elec, &
                                    restart, io_level, do_makov_payne,  &
                                    gamma_only, iverbosity, textfor,     &
                                    llondon, scf_must_converge, lxdm, ts_vdw
@@ -366,13 +368,6 @@ SUBROUTINE electrons_scf ( printout )
   !
   iter = 0
   dr2  = 0.0_dp
-  !
-  ! ... Convergence threshold for iterative diagonalization
-  ! ... for the first scf iteration of each ionic step (after the first),
-  ! ... the threshold is fixed to a default value of 1.D-6
-  !
-  IF ( istep > 0 ) ethr = 1.D-6
-  !
   IF ( restart ) CALL restart_in_electrons (iter, dr2, ethr, et )
   !
   WRITE( stdout, 9000 ) get_clock( 'PWSCF' )
@@ -382,7 +377,7 @@ SUBROUTINE electrons_scf ( printout )
   !
   CALL start_clock( 'electrons' )
   !
-  CALL flush_unit( stdout )
+  FLUSH( stdout )
   !
   ! ... calculates the ewald contribution to total energy
   !
@@ -402,7 +397,7 @@ SUBROUTINE electrons_scf ( printout )
   call create_scf_type ( rhoin )
   !
   WRITE( stdout, 9002 )
-  CALL flush_unit( stdout )
+  FLUSH( stdout )
   !
   CALL open_mix_file( iunmix, 'mix', exst )
   !
@@ -421,7 +416,7 @@ SUBROUTINE electrons_scf ( printout )
      !
      WRITE( stdout, 9010 ) iter, ecutwfc, mixing_beta
      !
-     CALL flush_unit( stdout )
+     FLUSH( stdout )
      !
      ! ... Convergence threshold for iterative diagonalization is
      ! ... automatically updated during self consistency
@@ -502,7 +497,7 @@ SUBROUTINE electrons_scf ( printout )
               ENDIF
            ENDIF
            !
-           IF ( first .AND. istep == 0 .AND. starting_pot == 'atomic' ) THEN
+           IF ( first .AND. starting_pot == 'atomic' ) THEN
               CALL ns_adj()
               IF (noncolin) THEN
                  rhoin%ns_nc = rho%ns_nc
@@ -735,8 +730,9 @@ SUBROUTINE electrons_scf ( printout )
      IF ( conv_elec ) THEN
         !
         ! ... if system is charged add a Makov-Payne correction to the energy
+        ! ... (not in case of hybrid functionals: it is added at the end)
         !
-        IF ( do_makov_payne ) CALL makov_payne( etot )
+        IF ( do_makov_payne .AND. printout/= 0 ) CALL makov_payne( etot )
         !
         ! ... print out ESM potentials if desired
         !
@@ -766,9 +762,9 @@ SUBROUTINE electrons_scf ( printout )
   WRITE( stdout, 9101 )
   WRITE( stdout, 9120 ) iter
   !
-10  CALL flush_unit( stdout )
+10  FLUSH( stdout )
   !
-  ! ... exiting: write (unless disables) the charge density to file
+  ! ... exiting: write (unless disabled) the charge density to file
   ! ... (also write ldaU ns coefficients and PAW becsum)
   !
   IF ( io_level > -1 ) CALL write_rho( rho, nspin )
@@ -1107,7 +1103,7 @@ SUBROUTINE electrons_scf ( printout )
        IF ( i_cons /= 0 .AND. i_cons < 4 ) &
             WRITE( stdout, 9073 ) lambda
        !
-       CALL flush_unit( stdout )
+       FLUSH( stdout )
        !
        RETURN
        !
