@@ -7,12 +7,12 @@
 !
 ! Original version by Minoru Otani (AIST) and Nicephore Bonnet (AIST).
 !
-! This module controls the Fictitious Charge Particle (FCP) for constnat-mu
+! This module controls the Fictitious Charge Particle (FCP) for constant-mu
 ! method developed by N. Bonnet, T. Morishita, O. Sugino, and M. Otani
 ! (see PRL 109, 266101 [2012]).
 !
 ! Constant-mu scheme with the boundary condition 'bc2' and 'bc3' enables
-! description of the system is connected to a potentiaostat which preserves
+! description of the system connected to a potentiostat which preserves
 ! the Fermi energy of the system as the target Fermi energy (mu).
 !
 !----------------------------------------------------------------------------
@@ -74,9 +74,7 @@ CONTAINS
       !
       REAL(DP) :: ekin, tau
       REAL(DP) :: temp_new, temp_av, elapsed_time, force
-      ! istep0 counts MD steps done during this run
-      ! (istep counts instead all MD steps, including those of previous runs)
-      INTEGER, SAVE :: istep0 = 0 
+      ! istep counts all MD steps, including those of previous runs
       LOGICAL  :: file_exists
 
       tau = nelec
@@ -112,11 +110,8 @@ CONTAINS
       ! ... elapsed_time is in picoseconds
       !
       elapsed_time = elapsed_time + dt*2.D0*au_ps
-      !
-      istep0= istep0+ 1
       istep = istep + 1
       !
-      !
       IF ( control_temp ) CALL apply_thermostat()
       !
       ! ... we first remove the component of the force along the
@@ -541,16 +536,14 @@ CONTAINS
       IF ( .NOT. ionode ) RETURN
       !
       IF ( lfcpopt ) THEN
-         WRITE( UNIT = stdout, FMT  = '(5x, &
-                  "-->FCP optimiser activated<--")' )
+         WRITE( UNIT = stdout, FMT  = '(5x,"-->FCP optimiser activated<--")' )
          WRITE( UNIT = stdout, FMT = 9056 ) fcp_mu*rytoev, fcp_mu
          WRITE( UNIT = stdout, FMT = 9057 ) tot_charge
          WRITE( UNIT = stdout, FMT = 9058 ) fcp_relax_step
          WRITE( UNIT = stdout, FMT = 9059 ) fcp_relax_crit*rytoev, &
                                          fcp_relax_crit
       ELSE IF ( lfcpdyn ) THEN
-         WRITE( UNIT = stdout, FMT  = '(5x, &
-                  "-->FCP optimiser activated<--")' )
+         WRITE( UNIT = stdout, FMT  = '(5x,"-->FCP optimiser activated<--")' )
          WRITE( UNIT = stdout, FMT = 9056 ) fcp_mu*rytoev, fcp_mu
          WRITE( UNIT = stdout, FMT = 9057 ) tot_charge
       END IF
