@@ -87,9 +87,6 @@ SUBROUTINE iosys()
   !
   USE force_mod,     ONLY : lforce, lstres, force
   !
-  USE gvecs,         ONLY : dual
-  USE gvect,         ONLY : ecutrho_ => ecutrho
-  !
   USE fft_base, ONLY : dfftp
   USE fft_base, ONLY : dffts
   !
@@ -140,8 +137,9 @@ SUBROUTINE iosys()
   !
   USE relax,         ONLY : epse, epsf, epsp, starting_scf_threshold
   !
+  USE extrapolation, ONLY : pot_order, wfc_order
   USE control_flags, ONLY : isolve, max_cg_iter, david, tr2, imix, gamma_only,&
-                            nmix, iverbosity, niter, pot_order, wfc_order, &
+                            nmix, iverbosity, niter, &
                             remove_rigid_rot_ => remove_rigid_rot, &
                             diago_full_acc_   => diago_full_acc, &
                             tolp_             => tolp, &
@@ -153,8 +151,7 @@ SUBROUTINE iosys()
                             lkpoint_dir_      => lkpoint_dir, &
                             tqr_              => tqr, &
                             io_level, ethr, lscf, lbfgs, lmd, &
-                            ldamped, lbands, llang, use_SMC,  &
-                            lconstrain, restart, twfcollect, &
+                            lbands, lconstrain, restart, twfcollect, &
                             llondon, do_makov_payne, lxdm, &
                             ts_vdw_           => ts_vdw, &
                             lecrpa_           => lecrpa, &
@@ -162,7 +159,6 @@ SUBROUTINE iosys()
   USE control_flags, ONLY: scf_must_converge_ => scf_must_converge
   !
   USE wvfct,         ONLY : nbnd_ => nbnd, &
-                            ecutwfc_ => ecutwfc, &
                             ecfixed_ => ecfixed, &
                             qcutz_   => qcutz, &
                             q2sigma_ => q2sigma
@@ -301,7 +297,7 @@ SUBROUTINE iosys()
   !
   INTEGER  :: ia, nt, inlc, ibrav_sg, ierr
   LOGICAL  :: exst, parallelfs
-  REAL(DP) :: theta, phi
+  REAL(DP) :: theta, phi, ecutwfc_pp, ecutrho_pp
   !
   !
   ! ... various initializations of control variables
@@ -341,7 +337,7 @@ SUBROUTINE iosys()
      CASE ( 'damp' )
         !
         lmd     = .true.
-        ldamped = .true.
+        calc    = 'vm'
         !
         ntcheck = nstep + 1
         !
@@ -362,14 +358,18 @@ SUBROUTINE iosys()
      SELECT CASE( trim( ion_dynamics ) )
      CASE( 'verlet' )
         !
-        CONTINUE
+        calc        = 'vd'
         !
-     CASE( 'langevin', 'langevin-smc', 'langevin+smc' )
+     CASE( 'langevin' )
         !
-        llang       = .true.
+        calc        = 'ld'
         temperature = tempw
-        use_SMC     = ( trim( ion_dynamics ) == 'langevin-smc' .OR. & 
-                        trim( ion_dynamics ) == 'langevin+smc' )
+        !
+     CASE( 'langevin-smc', 'langevin+smc' )
+        !
+        calc        = 'ls'
+        temperature = tempw
+        !
         !
      CASE DEFAULT
         !
@@ -384,7 +384,6 @@ SUBROUTINE iosys()
      lmd       = .true.
      lmovecell = .true.
      lforce    = .true.
-     ldamped   = .true.
      !
      epse =  etot_conv_thr
      epsf =  forc_conv_thr
@@ -410,7 +409,6 @@ SUBROUTINE iosys()
         !
         lbfgs = .true.
         lmd   = .false.
-        ldamped = .false.
         !
      CASE DEFAULT
         !
@@ -420,10 +418,10 @@ SUBROUTINE iosys()
         !
      END SELECT
      !
-     IF ( .not. ldamped .and. .not. lbfgs) &
-        CALL errore( 'iosys', 'calculation='// trim( calculation ) // &
-                   & ': incompatible ion (' // trim( ion_dynamics )// &
-                   & ') and cell dynamics ('// trim(cell_dynamics )// ')', 1 )
+     IF ( lbfgs .AND. TRIM(ion_dynamics) /= 'bfgs' ) &
+        CALL infomsg( 'iosys', 'calculation='// trim( calculation ) // &
+                   & ': ion dynamics ' // trim( ion_dynamics )// &
+                   & " ignored, 'bfgs' assumed" )
      !
   CASE( 'vc-md' )
      !
@@ -450,15 +448,15 @@ SUBROUTINE iosys()
      CASE DEFAULT
         !
         CALL errore( 'iosys', 'calculation=' // trim( calculation ) // &
-                   & ': ion_dynamics=' // trim( ion_dynamics ) // &
+                   & ': cell_dynamics=' // trim( cell_dynamics ) // &
                    & ' not supported', 1 )
         !
      END SELECT
      !
      IF ( trim( ion_dynamics ) /= 'beeman' ) &
-        CALL errore( 'iosys', 'calculation=' // trim( calculation ) // &
+        CALL infomsg( 'iosys', 'calculation=' // trim( calculation ) // &
                    & ': ion_dynamics=' // trim( ion_dynamics ) // &
-                   & ' not supported', 1 )
+                   & " ignored, assuming 'beeman'" )
      !
   CASE DEFAULT
      !
@@ -755,19 +753,6 @@ SUBROUTINE iosys()
      !
   ENDIF
   !
-  IF ( ecutrho <= 0.D0 ) THEN
-     !
-     dual = 4.D0
-     ecutrho = dual*ecutwfc
-     !
-  ELSE
-     !
-     dual = ecutrho / ecutwfc
-     IF ( dual <= 1.D0 ) &
-        CALL errore( 'iosys', 'invalid dual?', 1 )
-     !
-  ENDIF
-  !
   SELECT CASE( trim( restart_mode ) )
   CASE( 'from_scratch' )
      !
@@ -1108,8 +1093,6 @@ SUBROUTINE iosys()
   dfftp%nr1     = nr1
   dfftp%nr2     = nr2
   dfftp%nr3     = nr3
-  ecutrho_ = ecutrho
-  ecutwfc_ = ecutwfc
   ecfixed_ = ecfixed
   qcutz_   = qcutz
   q2sigma_ = q2sigma
@@ -1451,9 +1434,11 @@ SUBROUTINE iosys()
   !
   CALL init_dofree ( cell_dofree )
   !
-  ! ... read pseudopotentials (also sets DFT)
+  ! ... read pseudopotentials (also sets DFT and a few more variables)
+  ! ... returns values read from PP files into ecutwfc_pp, ecutrho_pp
   !
-  CALL readpp ( input_dft )
+  CALL readpp ( input_dft, .FALSE., ecutwfc_pp, ecutrho_pp )
+  CALL set_cutoff ( ecutwfc, ecutrho, ecutwfc_pp, ecutrho_pp )
   !
   ! ... set parameters of hybrid functionals
   !
@@ -1477,6 +1462,8 @@ SUBROUTINE iosys()
   END IF
   IF ( lstres .AND. dft_is_hybrid() .AND. npool > 1 )  CALL errore('iosys', &
          'stress for hybrid functionals not available with pools', 1)
+  IF ( lmovecell.AND. dft_is_hybrid() ) CALL errore('iosys',&
+         'Variable cell and hybrid XC not tested',1)
   !
   ! ... must be done AFTER dft is read from PP files and initialized
   ! ... or else the two following parameters will be overwritten
@@ -1553,6 +1540,47 @@ SUBROUTINE iosys()
   !
 END SUBROUTINE iosys
 !
+SUBROUTINE set_cutoff ( ecutwfc_in, ecutrho_in, ecutwfc_pp, ecutrho_pp )
+  !
+  ! Copy to modules the cutoffs, either read from input or from PP files
+  ! Values of ecutwfc and ecutrho are returned in ecutwfc_in, ecutrho_in
+  !
+  USE kinds, ONLY : dp
+  USE gvecs, ONLY : dual
+  USE gvect, ONLY : ecutrho
+  USE wvfct, ONLY : ecutwfc
+  !
+  IMPLICIT NONE
+  REAL(dp), INTENT(INOUT) :: ecutwfc_in, ecutrho_in
+  REAL(dp), INTENT(IN)    :: ecutwfc_pp, ecutrho_pp
+  !
+  IF( ecutwfc_in <= 0.0_dp ) THEN
+     IF( ecutwfc_pp <= 0.0_DP ) THEN
+        CALL errore( 'set_cutoff' ,' ecutwfc not set ',1)
+     ELSE
+        ecutwfc = ecutwfc_pp
+     END IF
+  ELSE
+     ecutwfc = ecutwfc_in
+  END IF
+  IF( ecutrho_in <= 0.0_dp ) THEN
+     IF( ecutwfc_in > 0.0_dp ) THEN
+        ecutrho = 4.0_dp*ecutwfc_in
+     ELSE IF( ecutrho_pp > 0.0_dp ) THEN
+        ecutrho = ecutrho_pp
+     ELSE IF( ecutwfc_pp > 0.0_dp ) THEN
+        ecutrho = 4.0_dp*ecutwfc_pp
+     END IF
+  ELSE
+     ecutrho = ecutrho_in
+  ENDIF
+  ecutwfc_in = ecutwfc
+  ecutrho_in = ecutrho
+  dual = ecutrho / ecutwfc
+  IF ( dual <= 1.0_dp ) CALL errore( 'set_cutoff', 'ecutrho <= ecutwfc?!?', 1 )
+  !
+END SUBROUTINE set_cutoff
+!
 !----------------------------------------------------------------------------
 SUBROUTINE read_cards_pw ( psfile, tau_format )
   !----------------------------------------------------------------------------
