@@ -12,7 +12,7 @@ SUBROUTINE write_casino_wfn(gather,blip,multiplicity,binwrite,single_precision_b
    USE ions_base, ONLY : nat, ntyp => nsp, ityp, tau, zv, atm
    USE cell_base, ONLY: omega, alat, tpiba2, at, bg
    USE run_info,  ONLY: title    ! title of the run
-   USE constants, ONLY: tpi, e2
+   USE constants, ONLY: tpi, e2, eps6
    USE ener, ONLY: ewld, ehart, etxc, vtxc, etot, etxcc, demet, ef
    USE fft_base,  ONLY: dfftp
    USE fft_interfaces, ONLY : fwfft
@@ -31,6 +31,7 @@ SUBROUTINE write_casino_wfn(gather,blip,multiplicity,binwrite,single_precision_b
    USE wavefunctions_module, ONLY : evc
    USE funct, ONLY : dft_is_meta
    USE mp_pools, ONLY: inter_pool_comm, intra_pool_comm, nproc_pool, me_pool
+   USE mp_bands, ONLY: intra_bgrp_comm
    USE mp, ONLY: mp_sum, mp_gather, mp_bcast, mp_get
    USE buffers,              ONLY : get_buffer
 
@@ -51,7 +52,7 @@ SUBROUTINE write_casino_wfn(gather,blip,multiplicity,binwrite,single_precision_b
    INTEGER :: jk2(nproc_pool), jspin2(nproc_pool), jbnd2(nproc_pool)
    INTEGER, ALLOCATABLE :: idx(:), igtog(:), gtoig(:)
    LOGICAL :: exst,dowrite
-   REAL(DP) :: ek, eloc, enl
+   REAL(DP) :: ek, eloc, enl, etot_
    INTEGER, EXTERNAL :: atomic_number
    REAL (DP), EXTERNAL :: ewald, w1gauss
 
@@ -363,11 +364,11 @@ CONTAINS
          DO ik = 1, nk
             ikk = ik + nk*(ispin-1)
             CALL gk_sort (xk (1, ikk), ngm, g, ecutwfc / tpiba2, npw, igk, g2kin)
-            CALL get_buffer (evc, nwordwfc, iunwfc, ikk )
+            IF( nks > 1 ) CALL get_buffer (evc, nwordwfc, iunwfc, ikk )
             CALL init_us_2 (npw, igk, xk (1, ikk), vkb)
             CALL calbec ( npw, vkb, evc, becp )
             !
-            ! -TS term for metals (ifany)
+            ! -TS term for metals (if any)
             !
             IF( degauss > 0.0_dp)THEN
                DO ibnd = 1, nbnd
@@ -431,8 +432,8 @@ CONTAINS
       ENDDO
 
 #ifdef __MPI
-      CALL mp_sum( eloc,  intra_pool_comm )
-      CALL mp_sum( ek,    intra_pool_comm )
+      CALL mp_sum( eloc,  intra_bgrp_comm )
+      CALL mp_sum( ek,    intra_bgrp_comm )
       CALL mp_sum( ek,    inter_pool_comm )
       CALL mp_sum( enl,   inter_pool_comm )
       CALL mp_sum( demet, inter_pool_comm )
@@ -455,7 +456,15 @@ CONTAINS
       !
       IF(dft_is_hybrid()) fock2 = 0.5_DP * exxenergy2()
       !
-      etot=(ek + (etxc-etxcc)+ehart+eloc+enl+ewld)+demet+fock2
+      etot_=(ek + (etxc-etxcc)+ehart+eloc+enl+ewld)+demet+fock2
+      !
+      IF ( ABS(etot-etot_) > ABS(eps6*etot) ) THEN
+         WRITE (stdout,'(5X,"Etot: ",f15.8," Ry from PWscf vs ", &
+                & f15.8," Ry from pw2casino!")') etot, etot_
+         CALL errore("pw2casino","Mismatch in computed energy",1)
+      ELSE
+         etot = etot_
+      END IF
       !
       CALL deallocate_bec_type (becp)
       DEALLOCATE (aux)
