@@ -479,7 +479,8 @@ SUBROUTINE pregterg( npw, npwx, nvec, nvecx, evc, ethr, &
   USE kinds,     ONLY : DP
   USE io_global, ONLY : stdout
   USE mp_bands,  ONLY : intra_bgrp_comm, inter_bgrp_comm, root_bgrp, nbgrp
-  USE mp_diag,   ONLY : ortho_comm, np_ortho, me_ortho, ortho_comm_id, leg_ortho
+  USE mp_diag,   ONLY : ortho_comm, np_ortho, me_ortho, ortho_comm_id, leg_ortho, &
+                        ortho_parent_comm
   USE descriptors,      ONLY : la_descriptor, descla_init, descla_local_dims
   USE parallel_toolkit, ONLY : dsqmdst, dsqmcll, dsqmred, dsqmsym
   USE mp,               ONLY : mp_bcast, mp_root_sum, mp_sum
@@ -1057,7 +1058,7 @@ CONTAINS
                  vtmp(:,1:notcl) = vl(:,1:notcl)
               END IF
 
-              CALL mp_bcast( vtmp(:,1:notcl), root, intra_bgrp_comm )
+              CALL mp_bcast( vtmp(:,1:notcl), root, ortho_parent_comm )
               ! 
               IF ( uspp ) THEN
                  !
@@ -1127,14 +1128,14 @@ CONTAINS
                  !
                  !  this proc sends his block
                  ! 
-                 CALL mp_bcast( vl(:,1:nc), root, intra_bgrp_comm )
+                 CALL mp_bcast( vl(:,1:nc), root, ortho_parent_comm )
                  CALL DGEMM( 'N', 'N', npw2, nc, nr, 1.D0, &
                           psi(1,ir), npwx2, vl, nx, beta, evc(1,ic), npwx2 )
               ELSE
                  !
                  !  all other procs receive
                  ! 
-                 CALL mp_bcast( vtmp(:,1:nc), root, intra_bgrp_comm )
+                 CALL mp_bcast( vtmp(:,1:nc), root, ortho_parent_comm )
                  CALL DGEMM( 'N', 'N', npw2, nc, nr, 1.D0, &
                           psi(1,ir), npwx2, vtmp, nx, beta, evc(1,ic), npwx2 )
               END IF
@@ -1185,14 +1186,14 @@ CONTAINS
                  !
                  !  this proc sends his block
                  ! 
-                 CALL mp_bcast( vl(:,1:nc), root, intra_bgrp_comm )
+                 CALL mp_bcast( vl(:,1:nc), root, ortho_parent_comm )
                  CALL DGEMM( 'N', 'N', npw2, nc, nr, 1.D0, &
                           spsi(1,ir), npwx2, vl, nx, beta, psi(1,nvec+ic), npwx2 )
               ELSE
                  !
                  !  all other procs receive
                  ! 
-                 CALL mp_bcast( vtmp(:,1:nc), root, intra_bgrp_comm )
+                 CALL mp_bcast( vtmp(:,1:nc), root, ortho_parent_comm )
                  CALL DGEMM( 'N', 'N', npw2, nc, nr, 1.D0, &
                           spsi(1,ir), npwx2, vtmp, nx, beta, psi(1,nvec+ic), npwx2 )
               END IF
@@ -1245,14 +1246,14 @@ CONTAINS
                  !
                  !  this proc sends his block
                  ! 
-                 CALL mp_bcast( vl(:,1:nc), root, intra_bgrp_comm )
+                 CALL mp_bcast( vl(:,1:nc), root, ortho_parent_comm )
                  CALL DGEMM( 'N', 'N', npw2, nc, nr, 1.D0, &
                           hpsi(1,ir), npwx2, vl, nx, beta, psi(1,nvec+ic), npwx2 )
               ELSE
                  !
                  !  all other procs receive
                  ! 
-                 CALL mp_bcast( vtmp(:,1:nc), root, intra_bgrp_comm )
+                 CALL mp_bcast( vtmp(:,1:nc), root, ortho_parent_comm )
                  CALL DGEMM( 'N', 'N', npw2, nc, nr, 1.D0, &
                           hpsi(1,ir), npwx2, vtmp, nx, beta, psi(1,nvec+ic), npwx2 )
               END IF
@@ -1313,11 +1314,12 @@ CONTAINS
 
            ! accumulate result on dm of root proc.
 
-           CALL mp_root_sum( work, dm, root, intra_bgrp_comm )
+           CALL mp_root_sum( work, dm, root, ortho_parent_comm )
 
         END DO
         !
      END DO
+     IF (ortho_parent_comm.ne.intra_bgrp_comm .and. nbgrp > 1) dm = dm/nbgrp
      !
      CALL dsqmsym( nbase, dm, nx, desc )
      !
@@ -1367,11 +1369,12 @@ CONTAINS
               !
               IF ( gstart == 2 ) &
                  CALL DGER( nr, nc, -1.D0, v( 1, ir ), npwx2, w(1,ii), npwx2, vtmp, nx )
+              IF (ortho_parent_comm.ne.intra_bgrp_comm .and. nbgrp > 1) vtmp = vtmp/nbgrp
 
               IF(  (desc%active_node > 0) .AND. (ipr-1 == desc%myr) .AND. (ipc-1 == desc%myc) ) THEN
-                 CALL mp_root_sum( vtmp(:,1:nc), dm(:,icc:icc+nc-1), root, intra_bgrp_comm )
+                 CALL mp_root_sum( vtmp(:,1:nc), dm(:,icc:icc+nc-1), root, ortho_parent_comm )
               ELSE
-                 CALL mp_root_sum( vtmp(:,1:nc), dm, root, intra_bgrp_comm )
+                 CALL mp_root_sum( vtmp(:,1:nc), dm, root, ortho_parent_comm )
               END IF
 
 
@@ -1399,7 +1402,7 @@ CONTAINS
            e( i + ic - 1 ) = hl( i, i )
         END DO
      END IF
-     CALL mp_sum( e(1:nbase), intra_bgrp_comm )
+     CALL mp_sum( e(1:nbase), ortho_parent_comm )
      RETURN
   END SUBROUTINE set_e_from_h
   !
