@@ -25,8 +25,8 @@
 
 
 #ifdef __IOTK_LOGICAL1
-#if 3 <= __IOTK_MAXRANK
-subroutine iotk_write_dat_LOGICAL1_3(unit,name,dat,dummy,attr,columns,sep,fmt,ierr)
+#if 0 <= __IOTK_MAXRANK
+subroutine iotk_write_dat_LOGICAL1_0(unit,name,dat,dummy,attr,columns,sep,fmt,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf, only : iotk_write_attr
@@ -39,7 +39,7 @@ subroutine iotk_write_dat_LOGICAL1_3(unit,name,dat,dummy,attr,columns,sep,fmt,ie
   integer, parameter :: this_kind = iotk_LOGICAL1
   integer,                                    intent(in)  :: unit
   character(len=*),                           intent(in)  :: name
-  LOGICAL (kind=this_kind),           intent(in)  :: dat (:,:,:) 
+  LOGICAL (kind=this_kind),           intent(in)  :: dat  
   type(iotk_dummytype),             optional              :: dummy
   character(len=*),                 optional, intent(in)  :: attr
   integer,                          optional, intent(in)  :: columns
@@ -126,7 +126,7 @@ call iotk_error_write(ierrl,"fmt",trim(fmt))
 call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
     goto 1
   end if
-  call iotk_write_attr(lattr,"size",size(dat),ierr=ierrl)
+  call iotk_write_attr(lattr,"size",1,ierr=ierrl)
   if(ierrl/=0) then
     call iotk_error_issue(ierrl,"iotk_write_dat",__FILE__,__LINE__)
 call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
@@ -254,15 +254,11 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
 call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
       goto 1
     end if
-    call iotk_write_begin(unit,iotk_tolower("LOGICAL"),lattr,ierr=ierrl,new_line=.true.)
+    call iotk_write_begin(unit,iotk_tolower("LOGICAL"),lattr,ierr=ierrl,new_line=.false.)
   end if
 !->
-  allocate(dattmp(size(dat)))
-#if defined(__IOTK_WORKAROUND3) || defined(__IOTK_WORKAROUND4)
-     call iotk_private_pack_LOGICAL1(dattmp,dat,size(dattmp),1)
-#else
-     dattmp = pack(dat,mask=.true.)
-#endif
+  allocate(dattmp(1))
+     dattmp(1) = dat
   if(binary) then
     if(raw) then
       write(lunit,iostat=iostat) (dattmp(itmp),itmp=1,size(dattmp))
@@ -334,7 +330,7 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
   end if
 !-<
   if (qe_syntax) then
-    call iotk_write_end(unit,iotk_tolower("LOGICAL"),indentation=.true.,ierr=ierrl)
+    call iotk_write_end(unit,iotk_tolower("LOGICAL"),indentation=.false.,ierr=ierrl)
     if(ierrl/=0) then
       call iotk_error_issue(ierrl,"iotk_write_dat",__FILE__,__LINE__)
 call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
@@ -355,11 +351,11 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_write_dat_LOGICAL1_3
+end subroutine iotk_write_dat_LOGICAL1_0
 
 
 
-subroutine iotk_scan_dat_LOGICAL1_3(unit,name,dat,dummy,attr,found,default,ierr)
+subroutine iotk_scan_dat_LOGICAL1_0(unit,name,dat,dummy,attr,found,default,ierr)
   use iotk_base
 !-<
   use iotk_unit_interf
@@ -375,9 +371,9 @@ subroutine iotk_scan_dat_LOGICAL1_3(unit,name,dat,dummy,attr,found,default,ierr)
   integer,                                   intent(in)  :: unit
   character(len=*),                          intent(in)  :: name
 #ifdef __IOTK_WORKAROUND6
-  LOGICAL(kind=this_kind)                        :: dat (:,:,:)
+  LOGICAL(kind=this_kind)                        :: dat 
 #else
-  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:,:)
+  LOGICAL(kind=this_kind),           intent(out) :: dat 
 #endif
   type(iotk_dummytype),            optional              :: dummy
 #ifdef __IOTK_WORKAROUND6
@@ -386,7 +382,7 @@ subroutine iotk_scan_dat_LOGICAL1_3(unit,name,dat,dummy,attr,found,default,ierr)
   character(len=*),                optional, intent(out) :: attr
 #endif
   logical,                         optional, intent(out) :: found
-  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:,:)
+  LOGICAL(kind=this_kind), optional, intent(in)  :: default 
   integer,                         optional, intent(out) :: ierr
   LOGICAL (kind=this_kind),              allocatable :: tmpdat(:)
   integer :: ierrl,ierrl2
@@ -523,13 +519,13 @@ call iotk_error_write(ierrl,"rtype",rtype(1:iotk_strlen(rtype)))
 call iotk_error_write(ierrl,"type","LOGICAL")
     goto 1
   end if
-  if(.not. (rsize==-1 .or. rsize==size(dat)) ) then
+  if(.not. (rsize==-1 .or. rsize==1) ) then
     call iotk_error_issue(ierrl,"iotk_scan_dat",__FILE__,__LINE__)
 call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
     goto 1
   end if
   if(rkind==-1) rkind = kind(dat)
-  allocate(tmpdat(size(dat)))
+  allocate(tmpdat(1))
   call iotk_scan_dat_aux(unit,tmpdat,rkind,rlen,fmt(1:iotk_strlen(fmt)),ierrl)
   if(ierrl/=0) then
     call iotk_error_issue(ierrl,"iotk_scan_dat",__FILE__,__LINE__)
@@ -540,11 +536,7 @@ call iotk_error_write(ierrl,"rkind",rkind)
 call iotk_error_write(ierrl,"rlen",rlen)
     goto 1
   end if
-#if defined(__IOTK_WORKAROUND3) || defined(__IOTK_WORKAROUND4)
-     call iotk_private_pack_LOGICAL1(dat,tmpdat,size(tmpdat),1)
-#else
-     dat = reshape(tmpdat,shape(dat))
-#endif
+     dat = tmpdat(1)
 1 continue
 !-<
   if ( allocated(tmpdat) ) deallocate(tmpdat)
@@ -582,11 +574,11 @@ call iotk_error_write(ierrl,"name",name)
   else
     if(ierrl>0 .or. (.not.present(found) .and. .not.present(default))) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_scan_dat_LOGICAL1_3
+end subroutine iotk_scan_dat_LOGICAL1_0
 
 !-<
 ! ... new procedure: scan dat when you are already inside the data tag
-subroutine iotk_scan_dat_inside_LOGICAL1_3(unit,dat,dummy,found,default,ierr)
+subroutine iotk_scan_dat_inside_LOGICAL1_0(unit,dat,dummy,found,default,ierr)
   use iotk_base
   use iotk_unit_interf
   use iotk_attr_interf, only : iotk_scan_attr
@@ -599,14 +591,14 @@ subroutine iotk_scan_dat_inside_LOGICAL1_3(unit,dat,dummy,found,default,ierr)
   integer, parameter :: this_kind = iotk_LOGICAL1
   integer,                                   intent(in)  :: unit
 #ifdef __IOTK_WORKAROUND6
-  LOGICAL(kind=this_kind)                        :: dat (:,:,:)
+  LOGICAL(kind=this_kind)                        :: dat 
 #else
-  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:,:)
+  LOGICAL(kind=this_kind),           intent(out) :: dat 
 #endif
 
   type(iotk_dummytype),            optional              :: dummy
   logical,                         optional, intent(out) :: found
-  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:,:)
+  LOGICAL(kind=this_kind), optional, intent(in)  :: default 
   integer,                         optional, intent(out) :: ierr
   LOGICAL (kind=this_kind),              allocatable :: tmpdat(:)
   character(len=20) :: tmpstr
@@ -698,14 +690,14 @@ call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
     return
   end if
 
-  if(.not. (rsize==-1 .or. rsize==size(dat)) ) then
+  if(.not. (rsize==-1 .or. rsize==1) ) then
     call iotk_error_issue(ierrl,"iotk_scan_dat_inside",__FILE__,__LINE__)
 call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
     goto 1
   end if
   if(rkind==-1) rkind = kind(dat)
 
-  allocate(tmpdat(size(dat)))
+  allocate(tmpdat(1))
   call iotk_scan_dat_aux(unit,tmpdat,rkind,rlen,fmt(1:iotk_strlen(fmt)),ierrl)
   if(ierrl/=0) then
     call iotk_error_issue(ierrl,"iotk_scan_dat_inside",__FILE__,__LINE__)
@@ -717,11 +709,7 @@ call iotk_error_write(ierrl,"rlen",rlen)
     goto 1
   end if
 
-#if defined(__IOTK_WORKAROUND3) || defined(__IOTK_WORKAROUND4)
-     call iotk_private_pack_LOGICAL1(dat,tmpdat,size(tmpdat),1)
-#else
-     dat = reshape(tmpdat,shape(dat))
-#endif
+     dat = tmpdat(1)
   deallocate(tmpdat)
 1 continue
   if(inside) then
@@ -750,15 +738,15 @@ call iotk_error_write(ierrl,"rname",rname)
     if(ierrl>0 .or. (.not.present(found) .and. .not.present(default))) call iotk_error_handler(ierrl)
   end if
 
-end subroutine iotk_scan_dat_inside_LOGICAL1_3
+end subroutine iotk_scan_dat_inside_LOGICAL1_0
 !->
 
 #endif
 #endif
 
-subroutine iotk_dat_dummy_LOGICAL1_3
+subroutine iotk_dat_dummy_LOGICAL1_0
   write(0,*)
-end subroutine iotk_dat_dummy_LOGICAL1_3
+end subroutine iotk_dat_dummy_LOGICAL1_0
 
 
 
@@ -773,8 +761,8 @@ end subroutine iotk_dat_dummy_LOGICAL1_3
 
 
 #ifdef __IOTK_LOGICAL1
-#if 4 <= __IOTK_MAXRANK
-subroutine iotk_write_dat_LOGICAL1_4(unit,name,dat,dummy,attr,columns,sep,fmt,ierr)
+#if 1 <= __IOTK_MAXRANK
+subroutine iotk_write_dat_LOGICAL1_1(unit,name,dat,dummy,attr,columns,sep,fmt,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf, only : iotk_write_attr
@@ -787,7 +775,7 @@ subroutine iotk_write_dat_LOGICAL1_4(unit,name,dat,dummy,attr,columns,sep,fmt,ie
   integer, parameter :: this_kind = iotk_LOGICAL1
   integer,                                    intent(in)  :: unit
   character(len=*),                           intent(in)  :: name
-  LOGICAL (kind=this_kind),           intent(in)  :: dat (:,:,:,:) 
+  LOGICAL (kind=this_kind),           intent(in)  :: dat (:) 
   type(iotk_dummytype),             optional              :: dummy
   character(len=*),                 optional, intent(in)  :: attr
   integer,                          optional, intent(in)  :: columns
@@ -1103,11 +1091,334 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_write_dat_LOGICAL1_4
+end subroutine iotk_write_dat_LOGICAL1_1
 
 
+recursive subroutine iotk_scan_dat_aux_LOGICAL1(unit,dat,rkind,rlen,fmt,ierr)
+  use iotk_base
+  use iotk_error_interf
+  use iotk_attr_interf, only: iotk_read
+  use iotk_scan_interf
+  use iotk_str_interf
+  use iotk_unit_interf
+  use iotk_misc_interf
+  use iotk_stream_interf
+  implicit none
+  integer, parameter :: this_kind = iotk_LOGICAL1
+  integer,                         intent(in)  :: unit
+#ifdef __IOTK_WORKAROUND6
+  LOGICAL(kind=this_kind)              :: dat (:)
+#else
+  LOGICAL(kind=this_kind), intent(out) :: dat (:)
+#endif
+  integer,                         intent(in)  :: rkind
+  integer,                         intent(in)  :: rlen
+  character(len=*),                intent(in)  :: fmt
+  integer,                         intent(out) :: ierr
+  integer(iotk_header_kind) :: idummy
+  logical :: raw,binary,stream
+  integer :: lunit
+  integer :: i
+#ifdef __IOTK_WORKAROUND3
+  integer :: j
+#endif
+  integer :: index,length,nexttag,iostat,altlength
+  type(iotk_unit), pointer :: this
+  character(len=iotk_linlenx) :: line,altline
+#ifdef __IOTK_LOGICAL2
+  LOGICAL (kind=iotk_LOGICAL2), allocatable :: dat2 (:)
+#endif
+#ifdef __IOTK_LOGICAL3
+  LOGICAL (kind=iotk_LOGICAL3), allocatable :: dat3 (:)
+#endif
+#ifdef __IOTK_LOGICAL4
+  LOGICAL (kind=iotk_LOGICAL4), allocatable :: dat4 (:)
+#endif
+  lunit = iotk_phys_unit(unit)
+  ierr = 0
+  iostat = 0
+  idummy = 0
+  call iotk_unit_get(lunit,pointer=this)
+  raw = .false.
+  if(associated(this)) then
+    raw = this%raw
+  end if
+  call iotk_inquire(lunit,binary,stream,ierr)
+  if(ierr/=0) then
+    call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+    return
+  end if
+  if(binary) then
+    select case(rkind)
+    case(kind(dat))
+      if(raw) then
+#ifdef __IOTK_WORKAROUND3
+        read(lunit,iostat=iostat) ( dat(j), j=1,ubound(dat,1) )
+#else
+        read(lunit,iostat=iostat) dat
+#endif
+        if(iostat/=0) then
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      else
+        if(stream) then
+          call iotk_stream_read(lunit,idummy,dat,ierr=ierr)
+          if(ierr/=0) then
+            call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+            return
+          end if
+        else
+#ifdef __IOTK_WORKAROUND3
+          read(lunit,iostat=iostat) idummy, ( dat(j), j=1,ubound(dat,1) )
+#else
+          read(lunit,iostat=iostat) idummy, dat
+#endif
+        end if
+        if(iostat/=0) then
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      end if
+#ifdef __IOTK_LOGICAL2
+    case(kind(dat2))
+      ! for the sake of completeness: if the file is raw, there are no
+      ! information about kind and this line cannot be reached
+      if(raw) then
+        call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+        return
+      end if
+      allocate(dat2(ubound(dat,1)))
+      if(stream) then
+        call iotk_stream_read(lunit,idummy,dat2,ierr=ierr)
+        if(ierr/=0) then
+          deallocate(dat2)
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      else
+        read(lunit,iostat=iostat) idummy,( dat2(i), i=1,ubound(dat2,1) )
+        if(iostat/=0) then
+          deallocate(dat2)
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      end if
+#ifdef __IOTK_WORKAROUND2
+      dat  = dat2 .and. .true.
+#else
+      dat = dat2
+#endif
+      deallocate(dat2)
+#endif
+#ifdef __IOTK_LOGICAL3
+    case(kind(dat3))
+      ! for the sake of completeness: if the file is raw, there are no
+      ! information about kind and this line cannot be reached
+      if(raw) then
+        call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+        return
+      end if
+      allocate(dat3(ubound(dat,1)))
+      if(stream) then
+        call iotk_stream_read(lunit,idummy,dat3,ierr=ierr)
+        if(ierr/=0) then
+          deallocate(dat3)
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      else
+        read(lunit,iostat=iostat) idummy,( dat3(i), i=1,ubound(dat3,1) )
+        if(iostat/=0) then
+          deallocate(dat3)
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      end if
+#ifdef __IOTK_WORKAROUND2
+      dat  = dat3 .and. .true.
+#else
+      dat = dat3
+#endif
+      deallocate(dat3)
+#endif
+#ifdef __IOTK_LOGICAL4
+    case(kind(dat4))
+      ! for the sake of completeness: if the file is raw, there are no
+      ! information about kind and this line cannot be reached
+      if(raw) then
+        call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+        return
+      end if
+      allocate(dat4(ubound(dat,1)))
+      if(stream) then
+        call iotk_stream_read(lunit,idummy,dat4,ierr=ierr)
+        if(ierr/=0) then
+          deallocate(dat4)
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      else
+        read(lunit,iostat=iostat) idummy,( dat4(i), i=1,ubound(dat4,1) )
+        if(iostat/=0) then
+          deallocate(dat4)
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+          return
+        end if
+      end if
+#ifdef __IOTK_WORKAROUND2
+      dat  = dat4 .and. .true.
+#else
+      dat = dat4
+#endif
+      deallocate(dat4)
+#endif
+    case default
+      call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,'Kind incompatibility')
+call iotk_error_write(ierr,"kind",rkind)
+    end select
+  else
+    if(raw) then
+#ifdef __IOTK_WORKAROUND3
+      read(lunit,fmt=*,iostat=iostat) ( dat(j), j=1,ubound(dat,1) )
+#else
+      read(lunit,fmt=*,iostat=iostat) dat
+#endif
+      if(iostat/=0) then
+        call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+        return
+      end if
+    else if(iotk_strcomp(fmt,"*")) then
+#ifdef __IOTK_WORKAROUND3
+      read(lunit,fmt=*,iostat=iostat) ( dat(j), j=1,ubound(dat,1) )
+#else
+      read(lunit,fmt=*,iostat=iostat) dat
+#endif
+      if(iostat/=0) then
+        call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+        return
+      end if
+    else if(iotk_strcomp(fmt,"!")) then
+      index = 0
+      do
+        call iotk_getline(lunit,line,length,ierr)
+        if(ierr/=0) then
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+          return
+        end if
+        nexttag = scan(line(1:length),"<")
+        if(nexttag==0) then
+          nexttag = length + 1
+        else
+! adjust the positioning if there is a tag on this line
+! implementation to be improved
+          backspace(lunit,iostat=iostat)
+          if(iostat/=0) then
+            call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+            return
+          end if
+          call iotk_getline(lunit,altline,altlength,ierr)
+          if(ierr/=0) then
+            call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+            return
+          end if
+          backspace(lunit,iostat=iostat)
+          if(iostat/=0) then
+            call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+            return
+          end if
+          read(lunit,"(a)",advance="no",iostat=iostat) altline(1:nexttag-1 + altlength - length)
+          if(iostat/=0) then
+            call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+            return
+          end if
+        end if
+        call iotk_str_clean(line(1:nexttag - 1))
+        call iotk_read(dat,line(1:nexttag - 1),index,ierr)
+        if(ierr/=0) then
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,'Error reading LOGICAL data')
+          return
+        end if
+        if(index == size(dat)) exit
+        if(nexttag/=length + 1) then
+          call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+          return
+        end if
+      end do
+    else
+#ifdef __IOTK_WORKAROUND3
+      read(lunit,fmt=fmt(1:iotk_strlen(fmt)),iostat=iostat) ( dat(j), j=1,ubound(dat,1) )
+#else
+      read(lunit,fmt=fmt(1:iotk_strlen(fmt)),iostat=iostat) dat
+#endif
+      if(iostat/=0) then
+        call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+call iotk_error_msg(ierr,' ')
+call iotk_error_write(ierr,"iostat",iostat)
+        return
+      end if
+    end if
+  end if
+  if(idummy/=0) then
+    call iotk_error_issue(ierr,"iotk_scan_dat_aux",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.27 ")
+    return
+  end if
+end subroutine iotk_scan_dat_aux_LOGICAL1
 
-subroutine iotk_scan_dat_LOGICAL1_4(unit,name,dat,dummy,attr,found,default,ierr)
+subroutine iotk_scan_dat_LOGICAL1_1(unit,name,dat,dummy,attr,found,default,ierr)
   use iotk_base
 !-<
   use iotk_unit_interf
@@ -1123,9 +1434,9 @@ subroutine iotk_scan_dat_LOGICAL1_4(unit,name,dat,dummy,attr,found,default,ierr)
   integer,                                   intent(in)  :: unit
   character(len=*),                          intent(in)  :: name
 #ifdef __IOTK_WORKAROUND6
-  LOGICAL(kind=this_kind)                        :: dat (:,:,:,:)
+  LOGICAL(kind=this_kind)                        :: dat (:)
 #else
-  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:,:,:)
+  LOGICAL(kind=this_kind),           intent(out) :: dat (:)
 #endif
   type(iotk_dummytype),            optional              :: dummy
 #ifdef __IOTK_WORKAROUND6
@@ -1134,7 +1445,7 @@ subroutine iotk_scan_dat_LOGICAL1_4(unit,name,dat,dummy,attr,found,default,ierr)
   character(len=*),                optional, intent(out) :: attr
 #endif
   logical,                         optional, intent(out) :: found
-  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:,:,:)
+  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:)
   integer,                         optional, intent(out) :: ierr
   LOGICAL (kind=this_kind),              allocatable :: tmpdat(:)
   integer :: ierrl,ierrl2
@@ -1330,11 +1641,11 @@ call iotk_error_write(ierrl,"name",name)
   else
     if(ierrl>0 .or. (.not.present(found) .and. .not.present(default))) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_scan_dat_LOGICAL1_4
+end subroutine iotk_scan_dat_LOGICAL1_1
 
 !-<
 ! ... new procedure: scan dat when you are already inside the data tag
-subroutine iotk_scan_dat_inside_LOGICAL1_4(unit,dat,dummy,found,default,ierr)
+subroutine iotk_scan_dat_inside_LOGICAL1_1(unit,dat,dummy,found,default,ierr)
   use iotk_base
   use iotk_unit_interf
   use iotk_attr_interf, only : iotk_scan_attr
@@ -1347,14 +1658,14 @@ subroutine iotk_scan_dat_inside_LOGICAL1_4(unit,dat,dummy,found,default,ierr)
   integer, parameter :: this_kind = iotk_LOGICAL1
   integer,                                   intent(in)  :: unit
 #ifdef __IOTK_WORKAROUND6
-  LOGICAL(kind=this_kind)                        :: dat (:,:,:,:)
+  LOGICAL(kind=this_kind)                        :: dat (:)
 #else
-  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:,:,:)
+  LOGICAL(kind=this_kind),           intent(out) :: dat (:)
 #endif
 
   type(iotk_dummytype),            optional              :: dummy
   logical,                         optional, intent(out) :: found
-  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:,:,:)
+  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:)
   integer,                         optional, intent(out) :: ierr
   LOGICAL (kind=this_kind),              allocatable :: tmpdat(:)
   character(len=20) :: tmpstr
@@ -1498,15 +1809,15 @@ call iotk_error_write(ierrl,"rname",rname)
     if(ierrl>0 .or. (.not.present(found) .and. .not.present(default))) call iotk_error_handler(ierrl)
   end if
 
-end subroutine iotk_scan_dat_inside_LOGICAL1_4
+end subroutine iotk_scan_dat_inside_LOGICAL1_1
 !->
 
 #endif
 #endif
 
-subroutine iotk_dat_dummy_LOGICAL1_4
+subroutine iotk_dat_dummy_LOGICAL1_1
   write(0,*)
-end subroutine iotk_dat_dummy_LOGICAL1_4
+end subroutine iotk_dat_dummy_LOGICAL1_1
 
 
 
@@ -1521,8 +1832,8 @@ end subroutine iotk_dat_dummy_LOGICAL1_4
 
 
 #ifdef __IOTK_LOGICAL1
-#if 5 <= __IOTK_MAXRANK
-subroutine iotk_write_dat_LOGICAL1_5(unit,name,dat,dummy,attr,columns,sep,fmt,ierr)
+#if 2 <= __IOTK_MAXRANK
+subroutine iotk_write_dat_LOGICAL1_2(unit,name,dat,dummy,attr,columns,sep,fmt,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf, only : iotk_write_attr
@@ -1535,7 +1846,7 @@ subroutine iotk_write_dat_LOGICAL1_5(unit,name,dat,dummy,attr,columns,sep,fmt,ie
   integer, parameter :: this_kind = iotk_LOGICAL1
   integer,                                    intent(in)  :: unit
   character(len=*),                           intent(in)  :: name
-  LOGICAL (kind=this_kind),           intent(in)  :: dat (:,:,:,:,:) 
+  LOGICAL (kind=this_kind),           intent(in)  :: dat (:,:) 
   type(iotk_dummytype),             optional              :: dummy
   character(len=*),                 optional, intent(in)  :: attr
   integer,                          optional, intent(in)  :: columns
@@ -1851,11 +2162,11 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.27 ")
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_write_dat_LOGICAL1_5
+end subroutine iotk_write_dat_LOGICAL1_2
 
 
 
-subroutine iotk_scan_dat_LOGICAL1_5(unit,name,dat,dummy,attr,found,default,ierr)
+subroutine iotk_scan_dat_LOGICAL1_2(unit,name,dat,dummy,attr,found,default,ierr)
   use iotk_base
 !-<
   use iotk_unit_interf
@@ -1871,9 +2182,9 @@ subroutine iotk_scan_dat_LOGICAL1_5(unit,name,dat,dummy,attr,found,default,ierr)
   integer,                                   intent(in)  :: unit
   character(len=*),                          intent(in)  :: name
 #ifdef __IOTK_WORKAROUND6
-  LOGICAL(kind=this_kind)                        :: dat (:,:,:,:,:)
+  LOGICAL(kind=this_kind)                        :: dat (:,:)
 #else
-  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:,:,:,:)
+  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:)
 #endif
   type(iotk_dummytype),            optional              :: dummy
 #ifdef __IOTK_WORKAROUND6
@@ -1882,7 +2193,7 @@ subroutine iotk_scan_dat_LOGICAL1_5(unit,name,dat,dummy,attr,found,default,ierr)
   character(len=*),                optional, intent(out) :: attr
 #endif
   logical,                         optional, intent(out) :: found
-  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:,:,:,:)
+  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:)
   integer,                         optional, intent(out) :: ierr
   LOGICAL (kind=this_kind),              allocatable :: tmpdat(:)
   integer :: ierrl,ierrl2
@@ -2078,11 +2389,11 @@ call iotk_error_write(ierrl,"name",name)
   else
     if(ierrl>0 .or. (.not.present(found) .and. .not.present(default))) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_scan_dat_LOGICAL1_5
+end subroutine iotk_scan_dat_LOGICAL1_2
 
 !-<
 ! ... new procedure: scan dat when you are already inside the data tag
-subroutine iotk_scan_dat_inside_LOGICAL1_5(unit,dat,dummy,found,default,ierr)
+subroutine iotk_scan_dat_inside_LOGICAL1_2(unit,dat,dummy,found,default,ierr)
   use iotk_base
   use iotk_unit_interf
   use iotk_attr_interf, only : iotk_scan_attr
@@ -2095,14 +2406,14 @@ subroutine iotk_scan_dat_inside_LOGICAL1_5(unit,dat,dummy,found,default,ierr)
   integer, parameter :: this_kind = iotk_LOGICAL1
   integer,                                   intent(in)  :: unit
 #ifdef __IOTK_WORKAROUND6
-  LOGICAL(kind=this_kind)                        :: dat (:,:,:,:,:)
+  LOGICAL(kind=this_kind)                        :: dat (:,:)
 #else
-  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:,:,:,:)
+  LOGICAL(kind=this_kind),           intent(out) :: dat (:,:)
 #endif
 
   type(iotk_dummytype),            optional              :: dummy
   logical,                         optional, intent(out) :: found
-  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:,:,:,:)
+  LOGICAL(kind=this_kind), optional, intent(in)  :: default (:,:)
   integer,                         optional, intent(out) :: ierr
   LOGICAL (kind=this_kind),              allocatable :: tmpdat(:)
   character(len=20) :: tmpstr
@@ -2246,15 +2557,15 @@ call iotk_error_write(ierrl,"rname",rname)
     if(ierrl>0 .or. (.not.present(found) .and. .not.present(default))) call iotk_error_handler(ierrl)
   end if
 
-end subroutine iotk_scan_dat_inside_LOGICAL1_5
+end subroutine iotk_scan_dat_inside_LOGICAL1_2
 !->
 
 #endif
 #endif
 
-subroutine iotk_dat_dummy_LOGICAL1_5
+subroutine iotk_dat_dummy_LOGICAL1_2
   write(0,*)
-end subroutine iotk_dat_dummy_LOGICAL1_5
+end subroutine iotk_dat_dummy_LOGICAL1_2
 
 
 
